Experiment Imports — Map of Objects

Skip to main content
`Ctrl`+`K`

# Experiment Imports

add_coordinates_to_experiment(experiment_id: str, distance_id: str, embedding_id: str, instance_ids: list, dim: int = 2, file_name: str | None = None) → dict

  Imports from a file precomputed coordinates of all the points, where each point refer to one instance

  Parameters:

    - experiment_id (str) – Name of the experiment.

    - distance_id (str) – Name of the distance.

    - embedding_id (str) – Name of the embedding.

    - instance_ids (list) – List of instance ids.

    - dim (int) – Dimension.

    - file_name (str) – Name of file in which the coordinates are stored.

  Returns:

    Coordinates.

  Return type:

    dict

add_distances_to_experiment(experiment_id: str, distance_id: str, instance_ids: list) -> (<class 'dict'>, <class 'dict'>, <class 'dict'>, <class 'dict'>)

  Imports precomputed distances between each pair of instances from a file while preparing an experiment.

  Parameters:

    - experiment_id (str) – Name of the experiment.

    - distance_id (str) – Name of the distance.

    - instance_ids (list) – List of the Ids.

  Returns:

    distances, times, stds, mappings

  Return type:

    (dict, dict, dict, dict)

get_values_from_csv_file(experiment_id: str, feature_id: str, feature_long_id: str | None = None, upper_limit: float = inf, lower_limit: float = -inf, column_id: str = 'value') → dict

  Imports values for a feature_id from a .csv file

  Parameters:

    - experiment_id (str) – Name of the experiment.

    - feature_id (str) – Name of the feature.

    - feature_long_id (str) – Long name of the feature.

    - upper_limit (float) – Upper limit for the values. If the value of a feature is greater than the upper limit, it is set to the upper limit.

    - lower_limit (float) – Lower limit fot the values. If the value of a feature is smaller than the lower limit, it is set to the lower limit.

    - column_id (str) – Name of the column to be imported.

  Returns:

    Feature dictionary.

  Return type:

    dict

import_distances_from_file(experiment_id: str, distance_id: str, instance_ids: list) → dict

  Imports distances between each pair of instances from a file.

  Parameters:

    - experiment_id (str) – Name of the experiment.

    - distance_id (str) – Name of the distance.

    - instance_ids (list) – List of the Ids.

  Returns:

    Distances.

  Return type:

    dict